@@ -29,6 +29,12 @@ FAILEDOPERATION_APMCONFIGINSTANCEID = 'FailedOperation.ApmConfigInstanceId'
 # 当前异步事件状态不支持此操作，请稍后重试。
 FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 
+# 登录信息验证失败，token 验证失败。
+FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
+
+# 请求role信息失败。
+FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
+
 # 复制函数失败。
 FAILEDOPERATION_COPYFAILED = 'FailedOperation.CopyFailed'
 
@@ -206,6 +212,9 @@ INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
 # Args 参数值有误。
 INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
 
+# AsyncRunEnable 取值不正确。
+INVALIDPARAMETERVALUE_ASYNCRUNENABLE = 'InvalidParameterValue.AsyncRunEnable'
+
 # 函数异步重试配置参数无效。
 INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerConfig'
 
@@ -278,12 +287,21 @@ INVALIDPARAMETERVALUE_DEADLETTERCONFIG = 'InvalidParameterValue.DeadLetterConfig
 # 默认Namespace无法创建。
 INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace'
 
+# DemoID  对应的函数模板 ，code 参数值有误，请确认后重试。
+INVALIDPARAMETERVALUE_DEMO = 'InvalidParameterValue.Demo'
+
+# DemoId 不存在。
+INVALIDPARAMETERVALUE_DEMOID = 'InvalidParameterValue.DemoId'
+
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
 # 环境变量DNS[OS_NAMESERVER]配置有误。
 INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
 
+# DynamicEnabled 参数传入错误。
+INVALIDPARAMETERVALUE_DYNAMICENABLED = 'InvalidParameterValue.DynamicEnabled'
+
 # EipConfig参数错误。
 INVALIDPARAMETERVALUE_EIPCONFIG = 'InvalidParameterValue.EipConfig'
 
@@ -338,6 +356,9 @@ INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
 # InlineZipFile非法。
 INVALIDPARAMETERVALUE_INLINEZIPFILE = 'InvalidParameterValue.InlineZipFile'
 
+# InstanceConcurrencyConfig 参数传入错误。
+INVALIDPARAMETERVALUE_INSTANCECONCURRENCYCONFIG = 'InvalidParameterValue.InstanceConcurrencyConfig'
+
 # InvokeType取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_INVOKETYPE = 'InvalidParameterValue.InvokeType'
 
@@ -356,6 +377,9 @@ INVALIDPARAMETERVALUE_LIMIT = 'InvalidParameterValue.Limit'
 # 参数超出长度限制。
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
+# MaxConcurrency 参数传入错误。
+INVALIDPARAMETERVALUE_MAXCONCURRENCY = 'InvalidParameterValue.MaxConcurrency'
+
 # Memory取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETERVALUE_MEMORY = 'InvalidParameterValue.Memory'
 
@@ -413,6 +437,9 @@ INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 # 不支持的函数版本。
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# 查询版本详情，版本参数传入错误。
+INVALIDPARAMETERVALUE_QUERYVERSION = 'InvalidParameterValue.QueryVersion'
+
 # 企业版镜像实例ID[RegistryId]传值错误。
 INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
 
@@ -542,6 +569,9 @@ LIMITEXCEEDED_PROVISIONTRIGGERACTION = 'LimitExceeded.ProvisionTriggerAction'
 # 定时触发间隔小于最大限制。
 LIMITEXCEEDED_PROVISIONTRIGGERINTERVAL = 'LimitExceeded.ProvisionTriggerInterval'
 
+# 配额超限。
+LIMITEXCEEDED_QUOTA = 'LimitExceeded.Quota'
+
 # 函数异步重试配置异步重试次数超过限制。
 LIMITEXCEEDED_RETRYNUM = 'LimitExceeded.RetryNum'
 
@@ -731,6 +761,9 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # 资源还有别名绑定，不支持当前操作，请解绑别名后重试。
 UNSUPPORTEDOPERATION_ALIASBIND = 'UnsupportedOperation.AliasBind'
 
+# 指定的配置AsyncRunEnable暂不支持，请修正后再试。
+UNSUPPORTEDOPERATION_ASYNCRUNENABLE = 'UnsupportedOperation.AsyncRunEnable'
+
 # Cdn不支持。
 UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 
